#include "configyyrename.h"

#line 3 "<stdout>"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 36
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	(yytext_ptr) -= (yy_more_len); \
	yyleng = (size_t) (yy_cp - (yytext_ptr)); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 82
#define YY_END_OF_BUFFER 83
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[624] =
    {   0,
        1,    1,   70,   70,   74,   74,   78,   78,   83,   81,
        1,   68,   69,    2,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   82,   70,   71,   82,   72,   82,   77,   74,   75,
       76,   82,   78,   79,   80,   82,   81,    0,    1,    2,
        2,    2,    2,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   70,    0,   77,    0,   74,
       78,    0,   81,   81,   81,   81,   81,   81,   81,   81,

       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   59,   81,   81,   81,
       81,   81,   81,   58,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       45,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
        4,   81,   16,   81,   81,   81,   25,   81,   81,   81,

       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   36,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   27,   81,
       81,   81,   81,   12,   13,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   40,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   47,

       81,    3,   81,   81,   81,   81,   81,   81,   81,   81,
       33,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   73,   81,   81,   81,   81,   81,
       81,   81,   17,   81,   81,   48,   24,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   14,   81,   31,
       81,   15,   81,   81,   81,   81,   10,   11,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   60,   62,
       81,   81,   81,   81,   81,   81,   81,   81,   28,   81,

       81,   32,   37,   81,   81,   29,   46,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,    6,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   19,   81,   81,   35,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,    8,
       81,   81,    5,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   26,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   42,   81,
       39,   81,   81,   81,   81,   81,   81,   81,   81,   21,

       81,   81,   81,   81,   38,   81,   81,   81,   81,   53,
        9,   81,   81,   81,   81,   41,   81,   81,   81,   81,
       81,   81,   81,   18,   81,   81,   81,   81,   30,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   61,   81,   66,   81,   81,   81,   81,   81,
       81,   81,   51,   81,   81,   81,    7,   22,   23,   81,
       50,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   49,   81,   81,   81,   81,   81,   54,
       20,   81,   67,   81,   81,   81,   56,   81,   81,   81,
       81,   55,   81,   81,   57,   52,   81,   81,   81,   81,

       81,   81,   43,   81,   81,   81,   81,   44,   81,   81,
       81,   34,   81,   81,   81,   81,   81,   81,   63,   64,
       81,   65,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    5,    6,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    7,    1,    1,    1,    1,    1,
        1,    8,    1,    9,    1,    1,    1,   10,    1,    1,
        1,    1,    1,    1,   11,   12,   13,   14,   15,   16,
       17,   18,   19,    1,   20,   21,   22,   23,   24,   25,
       26,   27,   28,   29,   30,   31,   32,   33,   34,   35,
        1,   36,    1,    1,    1,    1,   37,   38,   39,   40,

       41,   42,   43,   44,   45,    1,   46,   47,   48,   49,
       50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
       60,   61,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[62] =
    {   0,
        1,    2,    3,    4,    4,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1
    } ;

static yyconst flex_int16_t yy_base[633] =
    {   0,
        0,    0,   59,   62,   66,   70,   73,   76, 1726, 1689,
       80, 1758, 1758,   83,   63,   79,   89,   71,  110,   96,
       81,  116,  106,  136,  141,  128,  115,  151,  152,   78,
      154,   87, 1688, 1758, 1758, 1758,  144, 1687, 1718, 1758,
     1758,  193, 1680, 1758, 1758,  170, 1679,  197,  139,    0,
      204,    0,    0,  175,  184,  176,  135,  178,  198,  199,
      206,  203,  208,  217,  243,  185,  211,  233,  202,  239,
      230,  231,  247,  235,  240,  256,  244,  276,  257,  212,
      270,  281,  271,  274,  282, 1651,  220, 1616,  309, 1645,
     1610,  315,  273,  292,  298,  302,  301,  321,  303,  319,

      317,  328,  318,  324,  329,  337,  263,  266,  341,  336,
      347,  360,  349,  362,  361,  350,  364,  352,  351,  367,
      354,  386,  382,  380,  383,  388, 1599,  387,  403,  385,
      411,  393,  395, 1569,  406,  407,  421,  415,  412,  419,
      429,  432,  433,  435,  436,  437,  442,  443,  438,  468,
     1567,  458,  470,  465,  472,  459,  469,  466,  476,  477,
      462,  482,  497,  485,  499,  496,  517,  508,  512,  542,
      549,  509,  527,  531,  540,  557,  530,  552,  511,  543,
      556,  559,  566,  569,  570,  575,  581,  574,  597,  592,
     1566,  580, 1562,  599,  593,  598, 1561,  607,  612,  595,

      600,  621,  631,  619,  625,  629,  632,  635,  634,  643,
      655,  641,  645,  664,  648, 1556,  668,  670,  680,  667,
      682,  663,  676,  674,  685,  690,  698,  704,  702,  696,
      709,  716,  703,  706,  723,  725,  722,  727,  732,  747,
      741,  742,  733,  745,  759,  746,  740,  751,  749,  760,
      773,  778,  792,  764,  768,  779,  781,  785,  789,  796,
      791,  803,  795,  794,  804,  808,  810,  811, 1548,  829,
      826,  821,  836, 1470, 1462,  823,  819,  853,  845,  839,
      828,  832,  849,  850,  851,  860,  861, 1432,  874,  868,
      880,  886,  882,  887,  893,  883,  890,  900,  877, 1430,

      907, 1399,  892,  911,  903,  897,  925,  912,  921,  929,
     1394,  935,  923,  922,  933,  938,  943,  986,  952,  949,
      954,  955,  967,  957, 1380,  971,  956,  977,  984,  985,
      987,  988, 1349,  999,  990, 1341, 1331,  997,  993, 1003,
     1011, 1012, 1013, 1028, 1034, 1030, 1031, 1037, 1038, 1021,
     1025, 1029, 1044, 1048, 1039, 1058, 1059, 1067, 1076, 1078,
     1063, 1074, 1081, 1069, 1075, 1085, 1091, 1256, 1087, 1192,
     1101, 1169, 1093, 1096, 1097, 1120, 1108, 1065, 1100, 1127,
     1106, 1119, 1123, 1117, 1131, 1118, 1124, 1126, 1061, 1055,
     1147, 1143, 1122, 1114, 1144, 1166, 1170, 1151, 1022, 1172,

     1173,  968,  964, 1178, 1167,  960,  951, 1181, 1177, 1163,
     1184, 1168, 1155, 1165, 1190, 1198, 1195,  937, 1201, 1200,
     1197, 1202, 1205, 1206, 1208, 1210, 1213, 1216, 1218, 1237,
     1238, 1231, 1239, 1240, 1253,  909, 1251, 1241,  899, 1258,
     1265, 1259, 1263, 1248, 1264, 1279, 1266, 1261, 1274,  879,
     1286, 1282,  872, 1297, 1294, 1295, 1287, 1291, 1306, 1298,
     1314, 1313, 1317, 1307, 1308, 1334, 1319, 1329,  871, 1332,
     1347, 1352, 1342, 1348, 1355, 1351, 1357, 1354, 1345, 1360,
     1359, 1363, 1364, 1371, 1368, 1373, 1370, 1382,  867, 1386,
      753, 1395, 1396, 1385, 1388, 1397, 1405, 1406, 1414,  713,

     1390, 1412, 1418, 1425,  699, 1431, 1440, 1433, 1438,  638,
      606, 1429, 1423, 1443, 1449,  605, 1435, 1456, 1444, 1468,
     1450, 1484, 1474,  590, 1475, 1472, 1478, 1488,  586, 1479,
     1480, 1492, 1494, 1496, 1506, 1497, 1499, 1502, 1518, 1508,
     1503, 1504,  544, 1514,  516, 1525, 1530, 1520, 1529, 1528,
     1540, 1532,  503, 1534, 1544, 1547,  502,  491,  463, 1558,
      413, 1551, 1574, 1571, 1573, 1576, 1579, 1575, 1581, 1582,
     1584, 1585, 1586,  377, 1588, 1592, 1602, 1600, 1594,  311,
      304, 1607,  241, 1620, 1596, 1624,  196, 1622, 1625, 1626,
     1629,  191, 1612, 1633,  180,  149, 1635, 1628, 1649, 1652,

     1645, 1640,  144, 1658, 1661, 1667, 1644,  140, 1653, 1654,
     1669,  102, 1666, 1675, 1677, 1682, 1685, 1678,   85,   82,
     1696,   65, 1758, 1733, 1737, 1741,   92, 1745, 1749,   82,
     1751, 1753
    } ;

static yyconst flex_int16_t yy_def[633] =
    {   0,
      623,    1,  624,  624,  625,  625,  626,  626,  623,  627,
      623,  623,  623,  628,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  629,  623,  623,  623,  629,  630,  623,  623,
      623,  630,  631,  623,  623,  631,  627,  627,  623,  632,
      628,  632,  628,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  629,  629,  630,  630,  623,
      631,  631,  627,  627,  627,  627,  627,  627,  627,  627,

      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,

      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,

      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,

      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,

      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,

      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,    0,  623,  623,  623,  623,  623,  623,  623,
      623,  623
    } ;

static yyconst flex_int16_t yy_nxt[1820] =
    {   0,
       10,   11,   12,   12,   13,   14,   10,   10,   10,   10,
       15,   10,   16,   17,   10,   10,   10,   18,   19,   20,
       21,   10,   22,   23,   24,   10,   25,   26,   27,   28,
       29,   10,   30,   10,   31,   32,   15,   10,   16,   17,
       10,   10,   10,   18,   19,   20,   21,   10,   22,   23,
       24,   10,   25,   26,   27,   28,   29,   10,   30,   10,
       31,   34,   35,   36,   34,   35,   36,   39,   40,   40,
       41,   39,   40,   40,   41,   44,   44,   45,   44,   44,
       45,   49,   88,   54,   52,   50,   52,   52,   47,   62,
       47,   47,   47,   84,   37,   55,   56,   37,   48,   58,

       48,   42,   57,   59,   67,   42,   48,   60,   46,   54,
       66,   46,   61,   48,   48,   62,   48,   48,   53,   84,
       48,   55,   56,   63,   48,   58,   68,   80,   57,   59,
       67,   48,   64,   60,   65,   71,   66,   48,   61,   69,
       49,   48,   78,   70,   50,   48,   72,   86,   86,   63,
       48,   48,   68,   80,   73,   76,   79,   97,   64,   74,
       65,   71,   75,   48,   81,   69,   83,   77,   78,   70,
       48,   48,   72,   91,   91,   48,   48,   85,   82,   48,
       73,   76,   79,   97,   48,   74,   48,   48,   75,   48,
       81,   93,   83,   77,   88,   94,   88,   88,   47,   95,

       47,   47,   96,   85,   82,   52,   98,   52,   52,   99,
       48,   48,  101,   48,  100,   48,  102,   93,  110,   48,
       48,   94,  103,   86,   86,   95,   48,  111,   96,  104,
      113,   48,   98,   48,   48,   99,  126,   48,   48,   53,
      100,   48,  102,   48,  110,  105,   48,   48,  103,  106,
      107,  108,   48,  111,  112,  104,  113,  114,  115,  116,
      117,  118,  126,  119,  122,   48,   48,  125,   48,  147,
       48,  105,  148,  109,   48,   48,   48,  120,   48,   48,
      112,  121,   48,  114,  115,  116,  117,  118,  123,  119,
      122,   48,   48,  125,  127,  128,  132,  129,   48,  109,

      130,   48,  124,  120,  131,   48,   48,  121,   48,   48,
       88,   48,   88,   88,  123,  133,   48,   48,   91,   91,
      127,  128,  132,  129,  134,  135,  130,   48,  124,  136,
      131,  137,  138,   48,  139,  140,   48,   48,   48,   48,
      142,  133,  141,  144,  143,  151,   48,  145,  149,  150,
      134,  135,   48,   48,   48,  136,   48,  137,  138,   48,
      139,  140,  152,   48,   48,  146,  142,  154,  141,  144,
      143,   48,   48,  145,  153,  155,   48,  156,  157,  158,
      159,  160,   48,  162,   48,   48,   48,   48,  152,   48,
      161,  146,  163,  154,  167,   48,   48,   48,  170,   48,

      153,  155,   48,  156,  157,  158,  159,  160,  164,  162,
      165,  166,   48,  168,  169,   48,  161,   48,   48,  172,
       48,   48,   48,   48,  170,  171,  173,  178,   48,  174,
       48,  177,  176,  175,  164,  180,  165,  166,   48,  168,
      169,   48,   48,  179,  188,  172,   48,   48,   48,  184,
       48,  171,  173,  178,   48,  174,   48,  177,  176,  175,
      181,  183,  182,  185,   48,  186,  187,   48,   48,  179,
       48,   48,   48,   48,  189,  184,  190,   48,   48,  191,
      192,  193,  194,  195,  196,  197,  181,  183,  182,  185,
      199,  186,  187,   48,   48,  198,  200,   48,   48,  205,

       48,   48,  190,   48,   48,   48,  192,   48,  194,  195,
      196,   48,   48,  206,  207,  201,  199,   48,  227,  228,
       48,  198,  200,  202,  203,  205,   48,  220,  204,  208,
      211,   48,   48,  221,   48,  212,  225,   48,   48,  206,
      207,  201,  209,   48,   48,  210,   48,   48,  213,  202,
      203,   48,   48,  220,  204,  208,  211,  214,  216,  222,
      215,  212,   48,  223,  217,   48,   48,  224,  209,  218,
      226,  210,  231,  229,  230,   48,  219,   48,   48,   48,
      234,  232,  233,  214,   48,  222,  215,   48,  237,  223,
      217,   48,   48,  224,   48,  218,  226,  235,  231,  229,

      230,   48,  219,  236,   48,   48,  234,  232,  233,   48,
       48,  238,  239,  240,  237,   48,   48,  241,  243,  242,
      244,   48,  246,  235,  247,   48,  245,   48,   48,  236,
       48,  248,   48,   48,   48,   48,  251,  238,  239,  240,
       48,   48,   48,  241,  243,  242,  244,   48,  246,  249,
      247,  250,  245,  252,   48,  253,   48,  248,  255,  254,
       48,  257,  251,  256,   48,  258,   48,   48,  259,   48,
       48,  260,  269,   48,  262,  249,   48,  250,   48,  252,
       48,  253,  261,   48,  255,  254,  263,  257,  264,  256,
       48,  258,  267,  265,  259,  266,  270,  260,   48,   48,

      262,  271,   48,   48,  268,   48,  272,  274,  261,   48,
      273,   48,  263,  275,  264,   48,  276,   48,  267,  265,
       48,  266,  270,  278,  277,   48,  279,  271,  281,  280,
      268,   48,  272,   48,   48,  284,  273,   48,   48,   48,
      285,   48,  276,  282,   48,  283,  286,  291,   48,  278,
      277,   48,  279,  287,  281,  280,  288,   48,   48,  292,
       48,  284,   48,  289,  290,  293,  285,   48,   48,  282,
      295,  283,  286,  291,  294,   48,   48,   48,  298,  296,
       48,   48,   48,  297,   48,  292,   48,  300,   48,  289,
      290,  299,  303,  305,   48,   48,  295,  304,  301,   48,

      294,  302,  306,   48,  298,  296,  307,  308,   48,  297,
      309,  310,  311,   48,   48,  312,   48,  299,  303,  305,
       48,  313,  314,  304,   48,  315,   48,   48,  306,   48,
       48,   48,  307,  308,  317,  318,  309,  310,   48,   48,
      319,  312,  316,   48,  320,   48,   48,  313,  314,  322,
      321,  315,  323,  327,   48,  328,   48,  326,   48,  324,
      317,   48,  325,   48,   48,  329,  319,   48,  316,  333,
      320,   48,  331,  332,   48,  322,  321,  336,  323,  327,
       48,  328,  330,  326,   48,   48,   48,  334,   48,  337,
      335,  329,  338,  340,  339,   48,   48,  343,  331,  332,

      341,  342,   48,   48,  344,  346,   48,   48,  330,   48,
      349,  352,   48,  334,   48,   48,  335,   48,   48,  347,
      339,   48,   48,  343,  345,   48,  348,   48,   48,  351,
      344,  346,   48,  350,   48,   48,  349,  352,   48,  353,
      354,  355,   48,  356,   48,  347,   48,   48,  359,  357,
      345,  358,  348,  361,  360,  351,   48,   48,   48,  350,
       48,  368,  369,  370,   48,  353,  354,  355,   48,  356,
       48,  362,   48,   48,  359,  357,  372,  358,   48,  361,
      360,  373,  371,  375,   48,  374,   48,   48,  369,   48,
       48,   48,   48,  377,  378,   48,  382,  362,  363,   48,

      364,  376,   48,   48,  365,  366,   48,  373,  371,  375,
      367,  374,   48,  381,  379,  380,  384,  386,  387,   48,
       48,   48,   48,   48,  363,   48,  364,  376,   48,  383,
      365,  366,   48,  388,   48,  385,  367,  389,   48,  381,
      379,  380,  384,  390,  391,  392,   48,   48,   48,  396,
      395,  394,  398,  399,  393,  383,   48,   48,  397,  388,
       48,  385,  401,   48,   48,   48,   48,  402,  403,   48,
      391,  392,   48,   48,   48,  396,  395,  394,  398,   48,
      393,  400,  405,   48,  397,  406,  404,  407,  401,  408,
       48,  411,  409,   48,   48,  410,   48,  412,   48,  413,

       48,  415,   48,  417,   48,  418,  421,  400,  405,   48,
       48,   48,  404,   48,  414,  408,   48,  411,  409,  416,
       48,  410,   48,  412,  419,  413,   48,  415,   48,  417,
      420,   48,   48,  422,  423,   48,   48,  424,  425,  426,
      414,   48,  428,   48,  430,  416,  427,  434,  429,   48,
      419,  433,   48,   48,   48,   48,  420,   48,   48,   48,
      423,   48,   48,  424,  425,  426,   48,  431,  428,  432,
      430,  435,  427,  434,  429,  436,  437,  433,   48,   48,
      438,  439,   48,  440,  441,  442,   48,  443,  448,  445,
       48,  449,  444,  431,  446,  432,  447,  435,   48,  450,

       48,   48,   48,   48,   48,   48,  438,   48,   48,  440,
      453,  442,   48,   48,  448,  445,   48,  449,  444,   48,
      446,  451,  447,  452,  455,   48,  454,   48,  458,  456,
       48,  457,   48,   48,  459,   48,   48,   48,  460,  461,
       48,   48,  462,   48,  463,   48,  468,  451,   48,  452,
      455,   48,  454,   48,  458,  456,  465,  457,  464,  466,
      459,  467,  469,  470,  460,  461,   48,  480,  462,  471,
      463,  472,   48,   48,   48,   48,   48,  473,  475,  474,
      479,  476,  465,   48,  464,  466,   48,  467,   48,  470,
      478,   48,  477,   48,   48,  471,   48,  472,   48,   48,

       48,   48,  481,  473,  475,  474,  479,  476,  482,   48,
      483,  484,  485,  486,   48,  489,  478,   48,  477,  488,
      487,   48,   48,  491,  490,  494,   48,  492,  481,   48,
       48,  493,   48,   48,  482,  495,  483,  484,  485,  486,
      496,   48,   48,   48,  498,  488,  487,  497,   48,   48,
      490,  494,   48,  492,   48,  499,  500,  493,  501,  502,
      505,  495,  503,  506,   48,  504,   48,   48,  510,   48,
      498,  508,  511,  497,  507,  509,   48,   48,  512,  516,
       48,  499,   48,   48,   48,  502,   48,   48,  503,   48,
       48,  504,   48,  513,   48,   48,  517,  508,   48,   48,

      507,  509,  514,   48,  512,   48,   48,  515,   48,  518,
      519,  520,  523,  521,  524,   48,  522,   48,  527,  513,
       48,   48,  517,   48,  525,   48,  528,  529,  514,   48,
       48,   48,   48,  515,   48,  518,  519,  520,  523,  521,
       48,   48,  522,  526,  527,  530,  531,   48,  533,   48,
      525,  536,  528,   48,  532,  535,  534,  537,   48,  543,
       48,  539,  541,  538,   48,   48,   48,   48,   48,  526,
       48,  530,  531,   48,  533,   48,  540,  536,   48,   48,
      532,  535,  534,  537,   48,   48,  542,  539,  541,  538,
      544,   48,  546,  545,  548,  547,  549,   48,  552,  551,

      550,  553,  540,   48,  554,   48,  557,   48,  558,   48,
       48,  559,  542,   48,   48,   48,  555,  561,  546,   48,
      548,  547,  549,   48,  552,  551,  550,   48,  556,   48,
      554,   48,   48,  560,   48,  562,  563,   48,   48,   48,
      564,   48,  555,   48,  566,  565,  572,  569,  567,   48,
      568,  570,  571,   48,  556,   48,  574,  576,  573,  560,
       48,  562,  563,   48,   48,   48,  564,   48,  575,   48,
      566,  565,  572,  569,  567,   48,  568,  570,  571,   48,
      577,  578,   48,   48,  573,  580,   48,  579,  581,  582,
      583,   48,  584,   48,  575,  587,   48,   48,  585,  586,

      588,   48,   48,  592,   48,  595,   48,  578,   48,   48,
       48,   48,  589,  579,   48,  582,   48,   48,  584,   48,
       48,   48,  590,   48,  585,  586,  588,   48,  591,   48,
      593,   48,  594,  596,   48,   48,  597,   48,  589,  598,
      599,  601,   48,  600,  603,   92,   90,   48,  590,  608,
      604,   89,  602,  612,  591,   48,  593,   48,  594,   48,
       48,   48,  597,   48,   48,  598,  599,  601,   48,  600,
       48,  605,  606,  607,  609,   48,  604,  610,  602,   48,
       48,  613,  614,  616,   48,  611,   87,   48,   48,   48,
      615,  619,  617,   48,  620,  618,   48,  605,  606,  607,

      609,   48,   48,  610,   48,  622,  621,  613,  614,  616,
       48,  611,   48,   48,   48,   92,  615,   48,  617,   90,
       48,  618,   89,   87,   48,  623,  623,  623,  623,  623,
      623,   48,  621,   33,   33,   33,   33,   38,   38,   38,
       38,   43,   43,   43,   43,   51,   51,  623,   51,   86,
       86,   91,   91,   52,   52,  623,   52,    9,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,

      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623
    } ;

static yyconst flex_int16_t yy_chk[1820] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    3,    3,    3,    4,    4,    4,    5,    5,    5,
        5,    6,    6,    6,    6,    7,    7,    7,    8,    8,
        8,   11,  630,   15,   14,   11,   14,   14,   32,   18,
       32,   32,  627,   30,    3,   15,   16,    4,   15,   17,

      622,    5,   16,   17,   21,    6,   18,   17,    7,   15,
       20,    8,   17,   30,   16,   18,   21,  620,   14,   30,
      619,   15,   16,   19,   17,   17,   22,   27,   16,   17,
       21,   20,   19,   17,   19,   23,   20,  612,   17,   22,
       49,   23,   26,   22,   49,   19,   24,   37,   37,   19,
       27,   22,   22,   27,   24,   25,   26,   57,   19,   24,
       19,   23,   24,   26,   28,   22,   29,   25,   26,   22,
       57,   24,   24,   46,   46,  608,   25,   31,   28,  603,
       24,   25,   26,   57,  596,   24,   28,   29,   24,   31,
       28,   54,   29,   25,   42,   54,   42,   42,   48,   55,

       48,   48,   56,   31,   28,   51,   58,   51,   51,   59,
       54,   56,   61,   58,   60,  595,   62,   54,   66,   55,
       66,   54,   63,   87,   87,   55,  592,   67,   56,   64,
       69,  587,   58,   59,   60,   59,   80,   69,   62,   51,
       60,   61,   62,   63,   66,   64,   67,   80,   63,   65,
       65,   65,   64,   67,   68,   64,   69,   70,   71,   72,
       73,   74,   80,   75,   77,   71,   72,   79,   68,  107,
       74,   64,  108,   65,   70,   75,  583,   76,   65,   77,
       68,   76,   73,   70,   71,   72,   73,   74,   78,   75,
       77,   76,   79,   79,   81,   82,   93,   83,  107,   65,

       84,  108,   78,   76,   85,   81,   83,   76,   93,   84,
       89,   78,   89,   89,   78,   94,   82,   85,   92,   92,
       81,   82,   93,   83,   95,   96,   84,   94,   78,   97,
       85,   98,   99,   95,  100,  101,   97,   96,   99,  581,
      103,   94,  102,  105,  104,  110,  580,  106,  109,  109,
       95,   96,  101,  103,  100,   97,   98,   98,   99,  104,
      100,  101,  111,  102,  105,  106,  103,  113,  102,  105,
      104,  110,  106,  106,  112,  114,  109,  115,  116,  117,
      118,  119,  111,  121,  113,  116,  119,  118,  111,  121,
      120,  106,  122,  113,  126,  112,  115,  114,  130,  117,

      112,  114,  120,  115,  116,  117,  118,  119,  123,  121,
      124,  125,  574,  128,  129,  124,  120,  123,  125,  132,
      130,  122,  128,  126,  130,  131,  133,  139,  132,  135,
      133,  138,  137,  136,  123,  141,  124,  125,  129,  128,
      129,  135,  136,  140,  149,  132,  131,  139,  561,  145,
      138,  131,  133,  139,  140,  135,  137,  138,  137,  136,
      142,  144,  143,  146,  141,  147,  148,  142,  143,  140,
      144,  145,  146,  149,  150,  145,  152,  147,  148,  153,
      154,  155,  156,  157,  158,  159,  142,  144,  143,  146,
      161,  147,  148,  152,  156,  160,  162,  161,  559,  164,

      154,  158,  152,  150,  157,  153,  154,  155,  156,  157,
      158,  159,  160,  165,  166,  163,  161,  162,  179,  179,
      164,  160,  162,  163,  163,  164,  558,  172,  163,  167,
      168,  166,  163,  173,  165,  169,  177,  557,  553,  165,
      166,  163,  167,  168,  172,  167,  179,  169,  170,  163,
      163,  545,  167,  172,  163,  167,  168,  170,  171,  174,
      170,  169,  173,  175,  171,  177,  174,  176,  167,  171,
      178,  167,  182,  180,  181,  175,  171,  170,  180,  543,
      185,  183,  184,  170,  171,  174,  170,  178,  188,  175,
      171,  181,  176,  176,  182,  171,  178,  186,  182,  180,

      181,  183,  171,  187,  184,  185,  185,  183,  184,  188,
      186,  189,  190,  192,  188,  192,  187,  194,  196,  195,
      198,  529,  200,  186,  201,  524,  199,  190,  195,  187,
      200,  202,  189,  196,  194,  201,  204,  189,  190,  192,
      516,  511,  198,  194,  196,  195,  198,  199,  200,  203,
      201,  203,  199,  205,  204,  206,  202,  202,  208,  207,
      205,  210,  204,  209,  206,  211,  203,  207,  212,  209,
      208,  213,  222,  510,  215,  203,  212,  203,  210,  205,
      213,  206,  214,  215,  208,  207,  217,  210,  218,  209,
      211,  211,  221,  219,  212,  220,  223,  213,  222,  214,

      215,  224,  220,  217,  221,  218,  225,  227,  214,  224,
      226,  223,  217,  228,  218,  219,  229,  221,  221,  219,
      225,  220,  223,  231,  230,  226,  232,  224,  234,  233,
      221,  230,  225,  227,  505,  237,  226,  229,  233,  228,
      238,  234,  229,  235,  231,  236,  239,  243,  500,  231,
      230,  232,  232,  240,  234,  233,  240,  237,  235,  244,
      236,  237,  238,  241,  242,  245,  238,  239,  243,  235,
      247,  236,  239,  243,  246,  247,  241,  242,  250,  248,
      244,  246,  240,  249,  249,  244,  248,  252,  491,  241,
      242,  251,  254,  256,  245,  250,  247,  255,  253,  254,

      246,  253,  257,  255,  250,  248,  258,  259,  251,  249,
      260,  261,  262,  252,  256,  263,  257,  251,  254,  256,
      258,  264,  265,  255,  259,  266,  261,  253,  257,  264,
      263,  260,  258,  259,  268,  270,  260,  261,  262,  265,
      271,  263,  267,  266,  272,  267,  268,  264,  265,  276,
      273,  266,  277,  280,  277,  281,  272,  279,  276,  278,
      268,  271,  278,  281,  270,  282,  271,  282,  267,  286,
      272,  273,  284,  285,  280,  276,  273,  290,  277,  280,
      279,  281,  283,  279,  283,  284,  285,  287,  278,  291,
      289,  282,  292,  294,  293,  286,  287,  296,  284,  285,

      295,  295,  489,  290,  297,  299,  469,  453,  283,  289,
      303,  306,  299,  287,  450,  291,  289,  293,  296,  301,
      293,  292,  294,  296,  298,  297,  301,  303,  295,  305,
      297,  299,  306,  304,  439,  298,  303,  306,  305,  307,
      308,  309,  301,  310,  436,  301,  304,  308,  314,  312,
      298,  313,  301,  316,  315,  305,  309,  314,  313,  304,
      307,  319,  320,  321,  310,  307,  308,  309,  315,  310,
      312,  317,  418,  316,  314,  312,  323,  313,  317,  316,
      315,  324,  322,  327,  320,  326,  407,  319,  320,  321,
      322,  327,  324,  329,  330,  406,  335,  317,  318,  403,

      318,  328,  323,  402,  318,  318,  326,  324,  322,  327,
      318,  326,  328,  334,  331,  332,  339,  341,  342,  329,
      330,  318,  331,  332,  318,  335,  318,  328,  339,  338,
      318,  318,  338,  343,  334,  340,  318,  344,  340,  334,
      331,  332,  339,  345,  346,  347,  341,  342,  343,  350,
      349,  348,  352,  353,  347,  338,  350,  399,  351,  343,
      351,  340,  355,  344,  352,  346,  347,  356,  357,  345,
      346,  347,  348,  349,  355,  350,  349,  348,  352,  353,
      347,  354,  358,  354,  351,  359,  357,  360,  355,  361,
      390,  364,  362,  356,  357,  363,  389,  365,  361,  366,

      378,  369,  358,  373,  364,  374,  379,  354,  358,  362,
      365,  359,  357,  360,  367,  361,  363,  364,  362,  371,
      366,  363,  369,  365,  375,  366,  367,  369,  373,  373,
      376,  374,  375,  380,  381,  379,  371,  382,  383,  384,
      367,  381,  386,  377,  388,  371,  385,  394,  387,  394,
      375,  393,  384,  386,  382,  376,  376,  393,  383,  387,
      381,  388,  380,  382,  383,  384,  385,  391,  386,  392,
      388,  395,  385,  394,  387,  396,  397,  393,  392,  395,
      398,  400,  391,  401,  404,  405,  398,  408,  413,  410,
      413,  414,  409,  391,  411,  392,  412,  395,  410,  415,

      414,  396,  405,  412,  372,  397,  398,  400,  401,  401,
      419,  405,  409,  404,  413,  410,  408,  414,  409,  411,
      411,  416,  412,  417,  421,  415,  420,  370,  424,  422,
      417,  423,  421,  416,  425,  420,  419,  422,  426,  427,
      423,  424,  428,  425,  429,  426,  434,  416,  427,  417,
      421,  428,  420,  429,  424,  422,  431,  423,  430,  432,
      425,  433,  435,  437,  426,  427,  432,  448,  428,  438,
      429,  440,  430,  431,  433,  434,  438,  441,  443,  442,
      447,  444,  431,  444,  430,  432,  437,  433,  435,  437,
      446,  368,  445,  440,  442,  438,  448,  440,  443,  445,

      441,  447,  449,  441,  443,  442,  447,  444,  451,  449,
      452,  454,  455,  456,  446,  459,  446,  452,  445,  458,
      457,  451,  457,  461,  460,  464,  458,  462,  449,  455,
      456,  463,  454,  460,  451,  465,  452,  454,  455,  456,
      466,  459,  464,  465,  468,  458,  457,  467,  462,  461,
      460,  464,  463,  462,  467,  470,  471,  463,  472,  473,
      476,  465,  474,  477,  468,  475,  337,  470,  481,  466,
      468,  479,  482,  467,  478,  480,  336,  473,  483,  487,
      479,  470,  471,  474,  333,  473,  476,  472,  474,  478,
      475,  475,  477,  484,  481,  480,  488,  479,  482,  483,

      478,  480,  485,  485,  483,  487,  484,  486,  486,  490,
      492,  493,  496,  494,  497,  325,  495,  488,  501,  484,
      494,  490,  488,  495,  498,  501,  502,  503,  485,  311,
      492,  493,  496,  486,  302,  490,  492,  493,  496,  494,
      497,  498,  495,  499,  501,  504,  506,  502,  508,  499,
      498,  513,  502,  503,  507,  512,  509,  514,  513,  521,
      504,  517,  519,  515,  512,  300,  506,  288,  508,  499,
      517,  504,  506,  509,  508,  507,  518,  513,  514,  519,
      507,  512,  509,  514,  515,  521,  520,  517,  519,  515,
      522,  518,  523,  522,  526,  525,  527,  275,  531,  530,

      528,  532,  518,  520,  533,  274,  536,  526,  537,  523,
      525,  538,  520,  527,  530,  531,  534,  540,  523,  522,
      526,  525,  527,  528,  531,  530,  528,  532,  535,  533,
      533,  534,  536,  539,  537,  541,  542,  538,  541,  542,
      544,  535,  534,  540,  547,  546,  554,  550,  548,  544,
      549,  551,  552,  539,  535,  548,  556,  562,  555,  539,
      546,  541,  542,  550,  549,  547,  544,  552,  560,  554,
      547,  546,  554,  550,  548,  551,  549,  551,  552,  555,
      563,  564,  556,  269,  555,  566,  562,  565,  567,  568,
      569,  216,  570,  560,  560,  573,  197,  193,  571,  572,

      575,  191,  151,  579,  134,  585,  564,  564,  565,  563,
      568,  566,  576,  565,  567,  568,  569,  570,  570,  571,
      572,  573,  577,  575,  571,  572,  575,  576,  578,  579,
      582,  585,  584,  586,  127,  578,  588,  577,  576,  589,
      590,  593,  582,  591,  597,   91,   90,  593,  577,  602,
      598,   88,  594,  607,  578,  584,  582,  588,  584,  586,
      589,  590,  588,  598,  591,  589,  590,  593,  594,  591,
      597,  599,  600,  601,  604,  602,  598,  605,  594,  607,
      601,  609,  610,  613,  599,  606,   86,  600,  609,  610,
      611,  616,  614,  604,  617,  615,  605,  599,  600,  601,

      604,  613,  606,  605,  611,  621,  618,  609,  610,  613,
      614,  606,  615,  618,   47,   43,  611,  616,  614,   39,
      617,  615,   38,   33,   10,    9,    0,    0,    0,    0,
        0,  621,  618,  624,  624,  624,  624,  625,  625,  625,
      625,  626,  626,  626,  626,  628,  628,    0,  628,  629,
      629,  631,  631,  632,  632,    0,  632,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,

      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
static int yy_more_flag = 0;
static int yy_more_len = 0;
#define yymore() ((yy_more_flag) = 1)
#define YY_MORE_ADJ (yy_more_len)
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "configlexer.lex"
#line 2 "configlexer.lex"
/*
 * configlexer.lex - lexical analyzer for NSD config file
 *
 * Copyright (c) 2001-2006, NLnet Labs. All rights reserved
 *
 * See LICENSE for the license.
 *
 */

#include "config.h"

#include <ctype.h>
#include <errno.h>
#include <string.h>
#include <strings.h>

#include "options.h"
#include "configyyrename.h"
#include "configparser.h"
void c_error(const char *message);

#if 0
#define LEXOUT(s)  printf s /* used ONLY when debugging */
#else
#define LEXOUT(s)
#endif

struct inc_state {
	const char* filename;
	int line;
};
static struct inc_state parse_stack[MAXINCLUDES];
static YY_BUFFER_STATE include_stack[MAXINCLUDES];
static int config_include_stack_ptr = 0;

static void config_start_include(const char* filename)
{
	FILE *input;
	if(strlen(filename) == 0) {
		c_error_msg("empty include file name");
		return;
	}
	if(config_include_stack_ptr >= MAXINCLUDES) {
		c_error_msg("includes nested too deeply, skipped (>%d)", MAXINCLUDES);
		return;
	}
	if (cfg_parser->chroot) {
		int l = strlen(cfg_parser->chroot); /* chroot has trailing slash */
		if (strncmp(cfg_parser->chroot, filename, l) != 0) {
			c_error_msg("include file '%s' is not relative to chroot '%s'",
				filename, cfg_parser->chroot);
			return;
		}
		filename += l - 1; /* strip chroot without trailing slash */
	}
	input = fopen(filename, "r");
	if(!input) {
		c_error_msg("cannot open include file '%s': %s",
			filename, strerror(errno));
		return;
	}
	LEXOUT(("switch_to_include_file(%s) ", filename));
	parse_stack[config_include_stack_ptr].filename = cfg_parser->filename;
	parse_stack[config_include_stack_ptr].line = cfg_parser->line;
	include_stack[config_include_stack_ptr] = YY_CURRENT_BUFFER;
	cfg_parser->filename = region_strdup(cfg_parser->opt->region, filename);
	cfg_parser->line = 1;
	yy_switch_to_buffer(yy_create_buffer(input,YY_BUF_SIZE));
	++config_include_stack_ptr;
}

static void config_end_include(void)
{
	--config_include_stack_ptr;
	cfg_parser->filename = parse_stack[config_include_stack_ptr].filename;
	cfg_parser->line = parse_stack[config_include_stack_ptr].line;
	yy_delete_buffer(YY_CURRENT_BUFFER);
	yy_switch_to_buffer(include_stack[config_include_stack_ptr]);
}

#ifndef yy_set_bol /* compat definition, for flex 2.4.6 */
#define yy_set_bol(at_bol) \
        { \
	        if ( ! yy_current_buffer ) \
	                yy_current_buffer = yy_create_buffer(yyin,YY_BUF_SIZE ); \
	        yy_current_buffer->yy_ch_buf[0] = ((at_bol)?'\n':' '); \
        }
#endif

#define YY_NO_INPUT 1
#line 95 "configlexer.lex"
#ifndef YY_NO_UNPUT
#define YY_NO_UNPUT 1
#endif
#ifndef YY_NO_INPUT
#define YY_NO_INPUT 1
#endif

#line 1162 "<stdout>"

#define INITIAL 0
#define quotedstring 1
#define include 2
#define include_quoted 3

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

yy_size_t yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 113 "configlexer.lex"

#line 1347 "<stdout>"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		(yy_more_len) = 0;
		if ( (yy_more_flag) )
			{
			(yy_more_len) = (yy_c_buf_p) - (yytext_ptr);
			(yy_more_flag) = 0;
			}
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 624 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1758 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 114 "configlexer.lex"
{ LEXOUT(("SP ")); /* ignore */ }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 115 "configlexer.lex"
{ LEXOUT(("comment(%s) ", yytext)); /* ignore */ }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 116 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_SERVER;}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 117 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_NAME;}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 118 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_IP_ADDRESS;}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 119 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_IP_ADDRESS;}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 120 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_IP_TRANSPARENT;}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 121 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_DEBUG_MODE;}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 122 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_HIDE_VERSION;}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 123 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_IP4_ONLY;}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 124 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_IP6_ONLY;}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 125 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_DO_IP4;}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 126 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_DO_IP6;}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 127 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_DATABASE;}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 128 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_IDENTITY;}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 129 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_NSID;}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 130 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_LOGFILE;}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 131 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_SERVER_COUNT;}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 132 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_TCP_COUNT;}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 133 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_TCP_QUERY_COUNT;}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 134 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_TCP_TIMEOUT;}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 135 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_IPV4_EDNS_SIZE;}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 136 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_IPV6_EDNS_SIZE;}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 137 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_PIDFILE;}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 138 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_PORT;}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 139 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_STATISTICS;}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 140 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_CHROOT;}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 141 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_USERNAME;}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 142 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_ZONESDIR;}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 143 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_ZONELISTFILE;}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 144 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_DIFFFILE;}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 145 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_XFRDFILE;}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 146 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_XFRDIR;}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 147 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_XFRD_RELOAD_TIMEOUT;}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 148 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_VERBOSITY;}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 149 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_ZONE;}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 150 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_ZONEFILE;}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 151 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_ALLOW_NOTIFY;}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 152 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_REQUEST_XFR;}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 153 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_NOTIFY;}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 154 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_NOTIFY_RETRY;}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 155 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_PROVIDE_XFR;}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 156 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_OUTGOING_INTERFACE;}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 157 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_ALLOW_AXFR_FALLBACK;}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 158 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_KEY;}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 159 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_ALGORITHM;}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 160 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_SECRET;}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 161 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_PATTERN;}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 162 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_INCLUDEPATTERN;}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 163 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_REMOTE_CONTROL;}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 164 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_CONTROL_ENABLE;}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 165 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_CONTROL_INTERFACE;}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 166 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_CONTROL_PORT;}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 167 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_SERVER_KEY_FILE;}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 168 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_SERVER_CERT_FILE;}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 169 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_CONTROL_KEY_FILE;}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 170 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_CONTROL_CERT_FILE;}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 171 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_AXFR;}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 172 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_UDP;}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 173 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_RRL_SIZE;}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 174 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_RRL_RATELIMIT;}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 175 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_RRL_SLIP;}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 176 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_RRL_IPV4_PREFIX_LENGTH;}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 177 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_RRL_IPV6_PREFIX_LENGTH;}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 178 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_RRL_WHITELIST_RATELIMIT;}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 179 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_RRL_WHITELIST;}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 180 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); return VAR_ZONEFILES_CHECK;}
	YY_BREAK
case 68:
/* rule 68 can match eol */
YY_RULE_SETUP
#line 181 "configlexer.lex"
{ LEXOUT(("NL\n")); cfg_parser->line++;}
	YY_BREAK
/* Quoted strings. Strip leading and ending quotes */
case 69:
YY_RULE_SETUP
#line 184 "configlexer.lex"
{ BEGIN(quotedstring); LEXOUT(("QS ")); }
	YY_BREAK
case YY_STATE_EOF(quotedstring):
#line 185 "configlexer.lex"
{
        yyerror("EOF inside quoted string");
        BEGIN(INITIAL);
}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 189 "configlexer.lex"
{ LEXOUT(("STR(%s) ", yytext)); yymore(); }
	YY_BREAK
case 71:
/* rule 71 can match eol */
YY_RULE_SETUP
#line 190 "configlexer.lex"
{ cfg_parser->line++; yymore(); }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 191 "configlexer.lex"
{
        LEXOUT(("QE "));
        BEGIN(INITIAL);
        yytext[yyleng - 1] = '\0';
	yylval.str = region_strdup(cfg_parser->opt->region, yytext);
        return STRING;
}
	YY_BREAK
/* include: directive */
case 73:
YY_RULE_SETUP
#line 200 "configlexer.lex"
{ LEXOUT(("v(%s) ", yytext)); BEGIN(include); }
	YY_BREAK
case YY_STATE_EOF(include):
#line 201 "configlexer.lex"
{
        yyerror("EOF inside include directive");
        BEGIN(INITIAL);
}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 205 "configlexer.lex"
{ LEXOUT(("ISP ")); /* ignore */ }
	YY_BREAK
case 75:
/* rule 75 can match eol */
YY_RULE_SETUP
#line 206 "configlexer.lex"
{ LEXOUT(("NL\n")); cfg_parser->line++;}
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 207 "configlexer.lex"
{ LEXOUT(("IQS ")); BEGIN(include_quoted); }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 208 "configlexer.lex"
{
	LEXOUT(("Iunquotedstr(%s) ", yytext));
	config_start_include(yytext);
	BEGIN(INITIAL);
}
	YY_BREAK
case YY_STATE_EOF(include_quoted):
#line 213 "configlexer.lex"
{
        yyerror("EOF inside quoted string");
        BEGIN(INITIAL);
}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 217 "configlexer.lex"
{ LEXOUT(("ISTR(%s) ", yytext)); yymore(); }
	YY_BREAK
case 79:
/* rule 79 can match eol */
YY_RULE_SETUP
#line 218 "configlexer.lex"
{ cfg_parser->line++; yymore(); }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 219 "configlexer.lex"
{
	LEXOUT(("IQE "));
	yytext[yyleng - 1] = '\0';
	config_start_include(yytext);
	BEGIN(INITIAL);
}
	YY_BREAK
case YY_STATE_EOF(INITIAL):
#line 225 "configlexer.lex"
{
	yy_set_bol(1); /* Set beginning of line, so "^" rules match.  */
	if (config_include_stack_ptr == 0) {
		yyterminate();
	} else {
		fclose(yyin);
		config_end_include();
	}
}
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 235 "configlexer.lex"
{ LEXOUT(("unquotedstr(%s) ", yytext)); 
			yylval.str = region_strdup(cfg_parser->opt->region, yytext); return STRING; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 238 "configlexer.lex"
ECHO;
	YY_BREAK
#line 1901 "<stdout>"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 624 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 624 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 623);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 238 "configlexer.lex"



